# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define _with_repolib 1

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/glassfish/jaf/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define jafver  1.1
%define jar_name activation

Name:           glassfish-jaf
Version:        1.1.0
Release:        5%{?dist}
Epoch:          0
Summary:        Glassfish - JavaBeans Activation Framework
License:        CDDL
Group:          Development/Java
URL:            http://glassfish.dev.java.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
BuildArch:      noarch
Source0:        %{name}-%{version}.tar.gz
#cvs -d :pserver:guest@cvs.dev.java.net:/cvs checkout glassfish/activation
Source1:	%{name}-%{version}-LICENCE.tar.gz
#cvs -d :pserver:guest@cvs.dev.java.net:/cvs checkout glassfish/bootstrap ... this tar is a tar of the legal folder under glassfish/bootstrap
Source2:	activation-1.1.pom
Source3:	%{name}-component-info.xml
Patch0:		%{name}-%{version}-ant-hack.patch

BuildRequires:  ant >= 0:1.6.5
BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  java-devel >= 0:1.4.2

Provides:       jaf = 0:%{jafver}
Provides:       jaf_api = 0:%{jafver}
Provides:       jaf_1_1_api
Provides:	activation

%description
JavaBeans Activation Framework. 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Provides:       jaf-javadoc = 0:%{jafver}

%description javadoc
%{summary}.

%if %{with_repolib}
%package repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	         Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n %{name}
%setup -q -n %{name} -T -D -a 1
%patch0 -p1

%if %{with_repolib}
tag=`echo %{version}-brew`
sed -i "s/@VERSION@/$tag/g" %{SOURCE3}
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE3}
%endif

%build
export CLASSPATH=
export OPT_JAR_LIST=:
ant release

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}
install -p -m 0644 build/release/%{jar_name}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
%add_to_maven_depmap javax.activation activation %{version} JPP %{name}

pushd $RPM_BUILD_ROOT%{_javadir}
ln -sf %{name}-%{version}.jar %{name}.jar
popd

#(cd $RPM_BUILD_ROOT%{_javadir}
#ln -s %{name}-%{version}.jar jaf-%{jafver}.jar
#ln -s %{name}-%{version}.jar jaf_api.jar
#ln -s %{name}-%{version}.jar jaf_1_1_api.jar
#ln -s %{name}-%{version}.jar jaf.jar
#)

# Do not ghost (which would be the right thing) because of a bug in the
# classpathx-jaf package and some RPM bug with ghosts (already fixed in RHEL-5)
#touch $RPM_BUILD_ROOT%{_javadir}/activation.jar
touch $RPM_BUILD_ROOT%{_javadir}/jaf.jar
touch $RPM_BUILD_ROOT%{_javadir}/jaf_api.jar
touch $RPM_BUILD_ROOT%{_javadir}/jaf_1_1_api.jar

# poms
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -pm 644 %{SOURCE2} \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}.pom

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/release/docs/javadocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	install -p -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	install -p -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
	install -p -m 644 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
	cp -p $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar $RPM_BUILD_ROOT%{repodirlib}/%{jar_name}.jar
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%{_sbindir}/update-alternatives --install %{_javadir}/jaf.jar jaf %{_javadir}/%{name}.jar 10100
%{_sbindir}/update-alternatives --install %{_javadir}/activation.jar activation %{_javadir}/%{name}.jar 10100
%{_sbindir}/update-alternatives --install %{_javadir}/jaf_api.jar jaf_api %{_javadir}/%{name}.jar 10100
%{_sbindir}/update-alternatives --install %{_javadir}/jaf_1_1_api.jar jaf_1_1_api %{_javadir}/%{name}.jar 10100

%preun
if [ "$1" = "0" ]; then
    %{_sbindir}/update-alternatives --remove jaf %{_javadir}/%{name}.jar
    %{_sbindir}/update-alternatives --remove jaf_api %{_javadir}/%{name}.jar
    %{_sbindir}/update-alternatives --remove activation %{_javadir}/%{name}.jar
    %{_sbindir}/update-alternatives --remove jaf_1_1_api %{_javadir}/%{name}.jar
fi

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc build/META-INF/LICENSE.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*
#%{_javadir}/jaf-%{jafver}.jar
%ghost %{_javadir}/jaf.jar
# Do not ghost (which would be the right thing) because of a bug in the
# classpathx-jaf package and some RPM bug with ghosts (already fixed in RHEL-5)
#%ghost %{_javadir}/activation.jar
%ghost %{_javadir}/jaf_api.jar
%ghost %{_javadir}/jaf_1_1_api.jar

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Tue Jul 22 2008 David Walluck <dwalluck@redhat.com> 0:1.1.0-5
- minor spec cleanups
- preserve timestamps when copying

* Fri Jul 18 2008 David Walluck <dwalluck@redhat.com> 0:1.1.0-4
- remove javadoc Requires(post)
- fix repolib location

* Fri Jul 18 2008 David Walluck <dwalluck@redhat.com> 0:1.1.0-3
- quiet setup
- use macros
- fix %%doc

* Fri Jul 18 2008 David Walluck <dwalluck@redhat.com> 0:1.1.0-2
- change repolib component id
- peroperly unpack sources
- update BuildRoot
- fix repolib permissions

* Mon Jun 02 2008 Permaine Cheung <pcheung@redhat.com> 0:1.1.0-1
- First JPP5 build

* Mon Mar 31 2008 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.11
- Removed the post/postun javadoc sections (Taken care of by install and files javadoc) 

* Fri Feb 15 2008 Fernando Nasser <fnasser@redhat.com> 0:1.1.0-0jpp.ep1.10
- Do not ghost (which would be the right thing) because of a bug in the
  classpathx-jaf package and some RPM bug with ghosts (already fixed in RHEL-5)

* Fri Nov 23 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1.0-0jpp.ep1.9
- Revert to sun-jaf name due to "buildmagic" 

* Fri Nov 23 2007 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.8
- Build with debug info

* Fri Nov 23 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1.0-0jpp.ep1.7
- Parametrize component-info contents
- Install real JAR into repolibdir

* Thu Nov 22 2007 Fernando Nasser <fnasser@redhat.com> 0:1.1.0-0jpp.ep1.6
- Fix installed name of component-info.xml

* Thu Nov 22 2007 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.5
- Adding component-info.xml
- Changed the repodir to glassfish/jaf 
- Insert alternatives for activation

* Tue Nov 20 2007 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.4
- Adding in the pom stuff 

* Thu Nov 15 2007 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.3
- Rebuild with 1.5 

* Thu Nov 15 2007 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.2
- Add jaf jaf_api jaf_1_1_api Provides and alternatives

* Tue Nov 13 2007 Clive Saldanha <csaldanh@redhat.com> 0:1.1.0-0jpp.ep1.1
- First release.
